@@ -14,13 +14,16 @@
 //! - Retry token loading when it fails
 //! - Attach the token to the request in the `x-aws-ec2-metadata-token` header
 
+use std::fmt::{Debug, Formatter};
 use std::future::Future;
 use std::pin::Pin;
 use std::sync::Arc;
 use std::time::{Duration, SystemTime};
 
 use aws_http::user_agent::UserAgentStage;
+use aws_smithy_async::rt::sleep::AsyncSleep;
 use aws_smithy_client::erase::DynConnector;
+use aws_smithy_client::retry;
 use aws_smithy_http::body::SdkBody;
 use aws_smithy_http::endpoint::Endpoint;
 use aws_smithy_http::middleware::AsyncMapRequest;
@@ -29,15 +32,13 @@ use aws_smithy_http::operation::Operation;
 use aws_smithy_http::operation::{Metadata, Request};
 use aws_smithy_http::response::ParseStrictResponse;
 use aws_smithy_http_tower::map_request::MapRequestLayer;
+use aws_smithy_types::timeout;
 use aws_types::os_shim_internal::TimeSource;
+
 use http::{HeaderValue, Uri};
 
 use crate::cache::ExpiringCache;
 use crate::imds::client::{ImdsError, ImdsErrorPolicy, TokenError};
-use aws_smithy_async::rt::sleep::AsyncSleep;
-use aws_smithy_client::retry;
-use aws_smithy_types::timeout::TimeoutConfig;
-use std::fmt::{Debug, Formatter};
 
 /// Token Refresh Buffer
 ///
@@ -84,7 +85,7 @@ impl TokenMiddleware {
         endpoint: Endpoint,
         token_ttl: Duration,
         retry_config: retry::Config,
-        timeout_config: TimeoutConfig,
+        timeout_config: timeout::Config,
         sleep_impl: Option<Arc<dyn AsyncSleep>>,
     ) -> Self {
         let inner_client = aws_smithy_client::Builder::new()
